TraMineRInternalNodeInit <- function(...){
	return(DTNInit(...))
}

TraMineRInternalSplitInit <- function(...){
	return(DTNsplit(...))
}

TraMineRInternalLayout <- function(...){
	return(TraMineR.setlayout(...))
}

TraMineRInternalSeqeage <- function(...){
	return(seqeage(...))
}

TraMineRInternalLegend <- function(...){
	return(TraMineR.legend(...))
}
